package com.bipt.intelligentapplicationorchestrationservice.controller;

import com.bipt.intelligentapplicationorchestrationservice.pojo.*;
import com.bipt.intelligentapplicationorchestrationservice.service.DatasetService;
import lombok.Getter;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/dataset")
@Slf4j
public class DatasetController {
    @Autowired
    private DatasetService datasetService;

    /**
     * 新增数据集
     * @param datasetDTO
     * @return
     */
    @PostMapping
    public OptResult save(@RequestBody DatasetDTO datasetDTO) {
        log.info("新增数据集:{}", datasetDTO);
        datasetService.save(datasetDTO);
        return OptResult.success();
    }

    @GetMapping("/page")
    public OptResult<PageResult> page(DatasetPageQueryDTO dataSetPageQueryDTO) {
        log.info("数据集分页查询:{}", dataSetPageQueryDTO);
        PageResult pageResult = datasetService.pageQuery(dataSetPageQueryDTO);
        return OptResult.success(pageResult);
    }


    /**
     * 修改数据集
     * @param datasetEntity
     * @return
     */
    @PutMapping
    public OptResult update(@RequestBody DatasetEntity datasetEntity){
        log.info("修改数据集",datasetEntity);
        datasetService.update(datasetEntity);
        return OptResult.success();
    }

    /**
     * 批量删除数据集
     * @param datasetIds 数据集ID列表
     * @return 操作结果
     */
    @DeleteMapping
    public OptResult<String> deleteBatch(@RequestBody List<Integer> datasetIds) {
        log.info("批量删除数据集，ID列表：{}", datasetIds);
        datasetService.deleteBatch(datasetIds);
        return OptResult.success("批量删除成功");
    }







}
